
import sys
import os

lineSep = java.lang.System.getProperty('line.separator')


def getWASHome(cell, node):
	varMap = AdminConfig.getid("/Cell:" + cell + "/Node:" + node + "/VariableMap:/")
	entries = AdminConfig.list("VariableSubstitutionEntry", varMap)
	eList = entries.split(lineSep)
	for entry in eList:
		name =  AdminConfig.showAttribute(entry, "symbolicName")
		if name == "WAS_INSTALL_ROOT":
			value = AdminConfig.showAttribute(entry, "value")
			return value
	#failover
	return java.lang.System.getenv('WAS_HOME')



def getSystemAppsDir(cell, node):
	fileSep = getFileSep(node)
	return getWASHome(cell, node) + fileSep + "systemApps"


def getSchedDir(cell, node):
	fileSep = getFileSep(node)
	return getSystemAppsDir(cell, node) + fileSep + "LongRunningScheduler.ear"


def getEndpointDir(cell, node):
	fileSep = getFileSep(node)
	return getSystemAppsDir(cell, node) + fileSep + "GEE.ear"


def getFileSep(node): 
	os = AdminTask.getNodePlatformOS("-nodeName " + node)
	if os == 'windows':
		return '\\'
	else:
		return '/'





def deployScheduler(cell, node, server):
	schedDir  = getSchedDir(cell, node)
	sysAppDir  = getSystemAppsDir(cell, node)
	try:
		print "Deploying LongRunningScheduler.ear"
		appListString = AdminApp.list("WebSphere:cell=" + cell + ",node=" + node + ",server=" + server)
		appList = appListString.splitlines()
		if "LongRunningScheduler" in appList:
			print "Scheduler is already installed."
			return 0
		AdminApp.install(schedDir, ['-node', node, '-server', server, '-appname', 'LongRunningScheduler', '-usedefaultbindings', '-zeroEarCopy', '-installed.ear.destination', '$(WAS_INSTALL_ROOT)/systemApps'])
		
		#Do virtual host mapping
		print "Mapping LongRunningScheduler to default_host"
		AdminApp.edit('LongRunningScheduler', ['-MapWebModToVH', [['.*', '.*', 'default_host']]])
	except:
		print "Exception occurred during deployScheduler(" + cell +", " + node + ", " + server + "):", sys.exc_info()
		return 1
	return 1



def deployEndpoint(cell, node, server):
	endpointDir  = getEndpointDir(cell, node)
	sysAppDir  = getSystemAppsDir(cell, node)
	try:
		print "Deploying GEE.ear"
		appListString = AdminApp.list("WebSphere:cell=" + cell + ",node=" + node + ",server=" + server)
		appList = appListString.splitlines()
		if "GEE" in appList:
			print "Endpoint is already installed."
			return 0
		AdminApp.install(endpointDir, ['-node', node, '-server', server, '-appname', 'GEE', '-usedefaultbindings', '-zeroEarCopy', '-installed.ear.destination', '$(WAS_INSTALL_ROOT)/systemApps', '-BackendIdSelection', [['.*', 'BatchJobExecutionEnvironmentEJBs.jar,.*', 'DERBY_V100_2']] ])
		
		#Do virtual host mapping
		print "Mapping GEE to default_host"
		AdminApp.edit('GEE', ['-MapWebModToVH', [['.*', '.*', 'default_host']]])
	except:
		print "Exception occurred during deployEndpoint(" + cell +", " + node + ", " + server + "):", sys.exc_info()
		return 1
	return 1



#------------------------------------------------------------------------------
# Main entry point
#------------------------------------------------------------------------------

cell = None
node = None
server = None

# set cell and node name from env
cell = os.environ.get('WAS_CELL')
node = os.environ.get('WAS_NODE')

# Try to get server from command-line arguments
i = 0
while i < len(sys.argv):
	if sys.argv[i] == "-server": 
		server = sys.argv[i + 1]	
	i = i + 1

if server == None:
	print "Defaluting to server1. Please specify a server with the \'-server\' option to configure grid scheduler and endpoint on a different server."
        server = "server1"
else:
        print "configuring scheduler and endpoint on the provided server"
        
print "Cell:  " + cell + ", Node:  " + node + ", Server:  " + server
	
if server != None and cell != None and node != None:
	retVal = deployScheduler(cell, node, server)
	if retVal == 1:
		retVal = deployEndpoint(cell, node, server)
	else:
		print "Skipping Endpoint installation"
	if retVal == 1:
		print "Saving Config ..."
		AdminConfig.save()
		print "Saved Config"
	else:
		print "Skipping Config Save"
